@@ -1,4 +1,5 @@
 import sys
+from os.path import join
 
 if sys.version_info < (3, 8):
     from importlib_metadata import distribution
@@ -9,7 +10,8 @@ _fallback = '(devel)'
 
 try:
     dist = distribution(__package__)
-    if dist.locate_file('__version__.py') == __file__:
+    installed = str(dist.locate_file(join(__package__, '__version__.py')))
+    if installed == __file__:
         __version__ = dist.version
     else:
         __version__ = _fallback
